@@ -82,6 +82,6 @@ class DBInterface(Generic[T], ILogger):
             )
             return updated_element["deleted"]
 
-    def increment_fields(self, *, search_filter: "Dict[str, Any]", fields: "Dict[str, int]") -> None:
+    def increment_fields(self, *, search_filter: "Dict[str, Any]", fields: "Dict[str, int]") -> bool:
         with self._db_connector as db:
-            db.increment_a_field(search_filter=search_filter, increment_query=fields)
+            return db.increment_a_field(search_filter=search_filter, increment_query=fields)
