@@ -6,6 +6,7 @@ class DeepLearningTask(str, Enum):
     SEMANTIC_SEGMENTATION = "semantic_segmentation"
     OBJECT_DETECTION = "object_detection"
     NLP = "nlp"
+    TEXT_RECOGNITION = "text_recognition"
     OTHER = "other"
 
 
@@ -14,4 +15,5 @@ class DeepLearningTaskLabel(str, Enum):
     SEMANTIC_SEGMENTATION = "Semantic Segmentation"
     OBJECT_DETECTION = "Object Detection"
     NLP = "NLP"
+    TEXT_RECOGNITION = "Text Recognition"
     OTHER = "Other"
